@@ -1,4 +1,4 @@
-# $Id: Feed.pm,v 1.6 2004/05/08 13:20:58 btrott Exp $
+# $Id: Feed.pm 911 2004-09-06 12:28:12Z btrott $
 
 package XML::Atom::Feed;
 use strict;
@@ -70,6 +70,32 @@ sub find_feeds {
 
 sub element_name { 'feed' }
 
+sub language {
+    my $feed = shift;
+    if (LIBXML) {
+        my $elem = $feed->{doc}->getDocumentElement;
+        if (@_) {
+            $elem->setAttributeNS('http://www.w3.org/XML/1998/namespace',
+                'lang', $_[0]);
+        }
+        return $elem->getAttribute('lang');
+    } else {
+        if (@_) {
+            $feed->{doc}->setAttribute('xml:lang', $_[0]);
+        }
+        return $feed->{doc}->getAttribute('xml:lang');
+    }
+}
+
+sub version {
+    my $feed = shift;
+    my $elem = LIBXML ? $feed->{doc}->getDocumentElement : $feed->{doc};
+    if (@_) {
+        $elem->setAttribute('version', $_[0]);
+    }
+    $elem->getAttribute('version');
+}
+
 sub entries_libxml {
     my $feed = shift;
     my @res = $feed->{doc}->getElementsByTagNameNS(NS, 'entry') or return;
@@ -205,6 +231,23 @@ the feed as a new I<E<lt>linkE<gt>> tag. For example:
     $link->href('http://www.example.com/');
     $feed->add_link($link);
 
+=head2 $feed->language
+
+Returns the language of the feed, from I<xml:lang>.
+
+=head2 $feed->author([ $author ])
+
+Returns an I<XML::Atom::Person> object representing the author of the entry,
+or C<undef> if there is no author information present.
+
+If I<$author> is supplied, it should be an I<XML::Atom::Person> object
+representing the author. For example:
+
+    my $author = XML::Atom::Person->new;
+    $author->name('Foo Bar');
+    $author->email('foo@bar.com');
+    $feed->author($author);
+
 =head1 AUTHOR & COPYRIGHT
 
 Please see the I<XML::Atom> manpage for author, copyright, and license
